---
# SPDX-FileCopyrightText: 2024 Nicco Kunzmann and Open Web Calendar Contributors <https://open-web-calendar.quelltext.eu/>
#
# SPDX-License-Identifier: CC-BY-SA-4.0

comments: true
date: 2024-06-10
---

# Self-Hosting and Gancio Integration

[Gancio] is a federated calendaring platform, integrated into the Fediverse.
The Open Web Calendar can be used to display events of [Gancio] calendars.

The [Antroposofía Chile] has used the Open Web Calendar to customize the calendar display.
of the events and adjust the style to thier hosting preferences.

[Antroposofía Chile]: https://antroposofiachile.net/home/
[Gancio]: https://gancio.org/
